==> wls-plugin-1.3-sources.jar: com/xebialabs/deployit/plugin/wls/ci/WlsSharedLibraryJarMapping.java <==
/*
 * Copyright (c) 2008-2010 XebiaLabs B.V. All rights reserved.
 *
 * Your use of XebiaLabs Software and Documentation is subject to the Personal
 * License Agreement.
 *
 * http://www.xebialabs.com/deployit-personal-edition-license-agreement
 *
 * You are granted a personal license (i) to use the Software for your own
 * personal purposes which may be used in a production environment and/or (ii)
 * to use the Documentation to develop your own plugins to the Software.
 * "Documentation" means the how to's and instructions (instruction videos)
 * provided with the Software and/or available on the XebiaLabs website or other
 * websites as well as the provided API documentation, tutorial and access to
 * the source code of the XebiaLabs plugins. You agree not to (i) lease, rent
 * or sublicense the Software or Documentation to any third party, or otherwise
 * use it except as permitted in this agreement; (ii) reverse engineer,
 * decompile, disassemble, or otherwise attempt to determine source code or
 * protocols from the Software, and/or to (iii) copy the Software or
 * Documentation (which includes the source code of the XebiaLabs plugins). You
 * shall not create or attempt to create any derivative works from the Software
 * except and only to the extent permitted by law. You will preserve XebiaLabs'
 * copyright and legal notices on the Software and Documentation. XebiaLabs
 * retains all rights not expressly granted to You in the Personal License
 * Agreement.
 */

package com.xebialabs.deployit.plugin.wls.ci;

import com.xebialabs.deployit.ConfigurationItem;
import com.xebialabs.deployit.ConfigurationItemProperty;
import com.xebialabs.deployit.ci.artifact.mapping.DeployableArtifactMapping;

/**
 * A mapping of a jar library to WebLogic middleware
 */
@SuppressWarnings("serial")
@ConfigurationItem(description = "A mapping of a JAR library to WebLogic middleware")
public class WlsSharedLibraryJarMapping extends DeployableArtifactMapping<WlsSharedLibraryJar, WlsTarget> implements WlsArtifactMapping {

    @ConfigurationItemProperty(required = false, description = "Deployment staging mode (default is stage")
    private WlsStageMode stageMode;

    @ConfigurationItemProperty(required = false, description = "Remote directory where the archives (ear, jar, war) are copied before deploying")
    protected String stagingDirectory;

    public WlsSharedLibraryJarMapping(WlsSharedLibraryJar source, WlsCluster target) {
        super(source, target);
    }

    public WlsSharedLibraryJarMapping(WlsSharedLibraryJar source, WlsCluster target, WlsStageMode stageMode, String stagingDirectory) {
        super(source, target);
        this.stageMode = stageMode;
        this.stagingDirectory = stagingDirectory;
    }

    public WlsStageMode getStageMode() {
        return (stageMode == null ? WlsStageMode.Stage : stageMode);
    }

    public String getStagingDirectory() {
        return stagingDirectory;
    }

    public WlsDeploymentPlan getDeploymentPlan() {
        //throw new RuntimeException("There is no deployment plan for Weblogic Library Jar files") ;
        return null;
    }

    public String getDeploymentPlanStagingDirectory() {
        //throw new RuntimeException("There is no stagin directory deployment plan for Weblogic Library Jar files") ;
        return null;
    }


}

==> wls-plugin-1.4-sources.jar: com/xebialabs/deployit/plugin/wls/ci/WlsSharedLibraryJarMapping.java <==
/*
 * Copyright (c) 2008-2010 XebiaLabs B.V. All rights reserved.
 *
 * Your use of XebiaLabs Software and Documentation is subject to the Personal
 * License Agreement.
 *
 * http://www.xebialabs.com/deployit-personal-edition-license-agreement
 *
 * You are granted a personal license (i) to use the Software for your own
 * personal purposes which may be used in a production environment and/or (ii)
 * to use the Documentation to develop your own plugins to the Software.
 * "Documentation" means the how to's and instructions (instruction videos)
 * provided with the Software and/or available on the XebiaLabs website or other
 * websites as well as the provided API documentation, tutorial and access to
 * the source code of the XebiaLabs plugins. You agree not to (i) lease, rent
 * or sublicense the Software or Documentation to any third party, or otherwise
 * use it except as permitted in this agreement; (ii) reverse engineer,
 * decompile, disassemble, or otherwise attempt to determine source code or
 * protocols from the Software, and/or to (iii) copy the Software or
 * Documentation (which includes the source code of the XebiaLabs plugins). You
 * shall not create or attempt to create any derivative works from the Software
 * except and only to the extent permitted by law. You will preserve XebiaLabs'
 * copyright and legal notices on the Software and Documentation. XebiaLabs
 * retains all rights not expressly granted to You in the Personal License
 * Agreement.
 */

package com.xebialabs.deployit.plugin.wls.ci;

import com.xebialabs.deployit.ConfigurationItem;
import com.xebialabs.deployit.ConfigurationItemProperty;
import com.xebialabs.deployit.ci.artifact.mapping.DeployableArtifactMapping;

/**
 * A mapping of a jar library to WebLogic middleware
 */
@SuppressWarnings("serial")
@ConfigurationItem(description = "A mapping of a JAR library to WebLogic middleware")
public class WlsSharedLibraryJarMapping extends DeployableArtifactMapping<WlsSharedLibraryJar, WlsTarget> implements WlsArtifactMapping {

	@ConfigurationItemProperty(required = false)
	private WlsDeploymentStrategy deploymentStrategy = WlsDeploymentStrategy.CLASSIC;
	
    @ConfigurationItemProperty(required = false, description = "Deployment staging mode (default is stage")
    private WlsStageMode stageMode;

    @ConfigurationItemProperty(required = false, description = "Remote directory where the archives (ear, jar, war) are copied before deploying")
    protected String stagingDirectory;

    public WlsSharedLibraryJarMapping(WlsSharedLibraryJar source, WlsCluster target) {
        super(source, target);
    }

    public WlsSharedLibraryJarMapping(WlsSharedLibraryJar source, WlsCluster target, WlsStageMode stageMode, String stagingDirectory) {
        super(source, target);
        this.stageMode = stageMode;
        this.stagingDirectory = stagingDirectory;
    }

    public WlsStageMode getStageMode() {
        return (stageMode == null ? WlsStageMode.Stage : stageMode);
    }

    public String getStagingDirectory() {
        return stagingDirectory;
    }

    public WlsDeploymentPlan getDeploymentPlan() {
        //throw new RuntimeException("There is no deployment plan for Weblogic Library Jar files") ;
        return null;
    }

    public String getDeploymentPlanStagingDirectory() {
        //throw new RuntimeException("There is no stagin directory deployment plan for Weblogic Library Jar files") ;
        return null;
    }

	public WlsDeploymentStrategy getDeploymentStrategy() {
		return deploymentStrategy;
	}

	public void setDeploymentStrategy(WlsDeploymentStrategy strategy) {
		this.deploymentStrategy = strategy;
	}

}
